@@ -11,13 +11,13 @@ from cdo_sdk_python.api.cloud_delivered_fmc_api import CloudDeliveredFMCApi
 from cdo_sdk_python.api.command_line_interface_api import CommandLineInterfaceApi
 from cdo_sdk_python.api.connectors_api import ConnectorsApi
 from cdo_sdk_python.api.inventory_api import InventoryApi
-from cdo_sdk_python.api.msp_next_gen_api import MSPNextGenApi
+from cdo_sdk_python.api.msp_api import MSPApi
 from cdo_sdk_python.api.meta_api import MetaApi
 from cdo_sdk_python.api.object_management_api import ObjectManagementApi
 from cdo_sdk_python.api.remote_access_monitoring_api import RemoteAccessMonitoringApi
 from cdo_sdk_python.api.search_api import SearchApi
 from cdo_sdk_python.api.tenant_management_api import TenantManagementApi
-from cdo_sdk_python.api.transaction_api import TransactionApi
+from cdo_sdk_python.api.transactions_api import TransactionsApi
 from cdo_sdk_python.api.users_api import UsersApi
 from cdo_sdk_python.api.swagger_redirect_controller_api import SwaggerRedirectControllerApi
 
